@@ -55,7 +55,7 @@ aggregate.sf = function(x, by, FUN, ..., do_union = TRUE, simplify = TRUE,
 			a_na[a$Group.1,] = a
 			a = a_na
 		}
-		a$Group.1 = NULL
+		a$Group.1 = NULL # remove
 		row.names(a) = row.names(by)
 		st_set_geometry(a, st_geometry(by))
 	} else {
@@ -88,25 +88,29 @@ aggregate.sf = function(x, by, FUN, ..., do_union = TRUE, simplify = TRUE,
 	}
 }
 
-
 #' Areal-weighted interpolation of polygon data
 #'
 #' Areal-weighted interpolation of polygon data
 #' @param x object of class \code{sf}, for which we want to aggregate attributes
 #' @param to object of class \code{sf} or \code{sfc}, with the target geometries
 #' @param extensive logical; if TRUE, the attribute variables are assumed to be spatially extensive (like population) and the sum is preserved, otherwise, spatially intensive (like population density) and the mean is preserved.
+#' @param ... ignored
 #' @examples
 #' nc = st_read(system.file("shape/nc.shp", package="sf"))
 #' g = st_make_grid(nc, n = c(20,10))
 #' a1 = st_interpolate_aw(nc["BIR74"], g, extensive = FALSE)
 #' sum(a1$BIR74) / sum(nc$BIR74) # not close to one: property is assumed spatially intensive
 #' a2 = st_interpolate_aw(nc["BIR74"], g, extensive = TRUE)
+#' # verify mass preservation (pycnophylactic) property:
 #' sum(a2$BIR74) / sum(nc$BIR74)
 #' a1$intensive = a1$BIR74
 #' a1$extensive = a2$BIR74
-#' plot(a1[c("intensive", "extensive")])
+#' plot(a1[c("intensive", "extensive")], key.pos = 4)
 #' @export
-st_interpolate_aw = function(x, to, extensive) {
+st_interpolate_aw = function(x, to, extensive, ...) UseMethod("st_interpolate_aw")
+
+#' @export
+st_interpolate_aw.sf = function(x, to, extensive, ...) {
 	if (!inherits(to, "sf") && !inherits(to, "sfc"))
 		stop("st_interpolate_aw requires geometries in argument to")
 	if (! all_constant(x))
@@ -130,6 +134,5 @@ st_interpolate_aw = function(x, to, extensive) {
 	x = aggregate(x, list(idx[,2]), sum)
 	df = st_sf(x, geometry = st_geometry(to)[x$Group.1])
 	df$...area_t = df$...area_st = df$...area_s = NULL
-	st_agr(df) = "aggregate"
-	df
+	st_set_agr(df, "aggregate")
 }
