@@ -13,7 +13,7 @@
 #' @param x object of class \code{sf} or \code{sfc}
 #' @param size sample size(s) requested; either total size, or a numeric vector with sample sizes for each feature geometry. When sampling polygons, the returned sampling size may differ from the requested size, as the bounding box is sampled, and sampled points intersecting the polygon are returned.
 #' @param ... ignored, or passed on to \link[base]{sample} for \code{multipoint} sampling
-#' @param type character; indicates the spatial sampling type; only \code{random} is implemented right now
+#' @param type character; indicates the spatial sampling type; one of \code{regular}, \code{hexagonal} and \code{regular}.
 #' @param exact logical; should the length of output be exactly
 #' the same as specified by \code{size}? \code{TRUE} by default. Only applies to polygons, and
 #' when \code{type = "random"}.
@@ -43,7 +43,7 @@
 #' }
 #' x = st_sfc(st_polygon(list(rbind(c(0,0),c(90,0),c(90,10),c(0,90),c(0,0))))) # NOT long/lat:
 #' plot(x)
-#' p_exact = st_sample(x, 1000)
+#' p_exact = st_sample(x, 1000, exact = TRUE)
 #' p_not_exact = st_sample(x, 1000, exact = FALSE)
 #' length(p_exact); length(p_not_exact)
 #' plot(st_sample(x, 1000), add = TRUE)
@@ -69,7 +69,7 @@
 #' st_sample(ls, 80)
 #' plot(st_sample(ls, 80))
 #' @export
-st_sample = function(x, size, ..., type = "random", exact = FALSE) {
+st_sample = function(x, size, ..., type = "random", exact = TRUE) {
 	x = st_geometry(x)
 	if (length(size) > 1) { # recurse:
 		size = rep(size, length.out = length(x))
