@@ -262,8 +262,14 @@ st_sf = function(..., agr = NA_agr_, row.names,
 				as.data.frame(x[-all_sfc_columns], 
 					stringsAsFactors = stringsAsFactors, optional = TRUE))
 
-	for (i in seq_along(all_sfc_names))
-		df[[ all_sfc_names[i] ]] = st_sfc(x[[ all_sfc_columns[i] ]], check_ring_dir = check_ring_dir)
+	if (check_ring_dir) { # process:
+		for (i in seq_along(all_sfc_names))
+			df[[ all_sfc_names[i] ]] = st_sfc(x[[ all_sfc_columns[i] ]], 
+				check_ring_dir = check_ring_dir)
+	} else { # copy:
+		for (i in seq_along(all_sfc_names))
+			df[[ all_sfc_names[i] ]] = x[[ all_sfc_columns[i] ]]
+	}
 
 	if (! missing(precision))
 		attr(df[[sfc_name]], "precision") = precision
