@@ -1,6 +1,6 @@
 ## dplyr methods:
 group_map.sf <- function(.tbl, .f, ...) {
-	 st_as_sf(NextMethod())
+	 st_as_sf(NextMethod()) # nocov
 }
 
 group_split.sf <- function(.tbl, ..., keep = TRUE) {
@@ -20,14 +20,9 @@ group_split.sf <- function(.tbl, ..., keep = TRUE) {
 #' nc = st_read(system.file("shape/nc.shp", package="sf"))
 #' nc %>% filter(AREA > .1) %>% plot()
 filter.sf <- function(.data, ..., .dots) {
-	#st_as_sf(NextMethod())
-	sf_column = attr(.data, "sf_column")
-	geom = .data[[sf_column]]
-	.data[[sf_column]] = seq_len(nrow(.data))
-	ret = NextMethod()
-	sel = ret[[sf_column]]
-	ret[[sf_column]] = geom[sel]
-	st_as_sf(ret, sf_column_name = sf_column)
+	agr = st_agr(.data)
+	class(.data) <- setdiff(class(.data), "sf")
+	.re_sf(NextMethod(), sf_column_name = attr(.data, "sf_column"), agr)
 }
 
 #' @name tidyverse
@@ -343,7 +338,7 @@ unnest.sf = function(data, ..., .preserve = NULL) {
 	# vector of variable names, using any valid dplyr (i.e. rlang)
 	# variable selection syntax. By default, with .preserve = NULL, this will be
 	# empty. Note: the !!! is from rlang.
-	preserve = tidyselect::vars_select(names(data), !!! rlang::enquo(.preserve))
+	preserve = tidyselect::vars_select(names(data), !!rlang::enquo(.preserve))
 	# Get the name of the geometry column(s)
 	sf_column_name = attr(data, "sf_column", exact = TRUE)
 	preserve_incl_sf = c(preserve, sf_column_name)
