@@ -381,8 +381,8 @@ Rcpp::List CPL_transform(Rcpp::List sfc, Rcpp::CharacterVector proj4) {
 	// transform geometries:
 	std::vector<OGRGeometry *> g = ogr_from_sfc(sfc, NULL);
 	if (g.size() == 0) {
-		dest->Release(); // #nocov
-		Rcpp::stop("CPL_transform: zero length geometry list"); // #nocov
+		dest->Release();
+		return sfc_from_ogr(g, true); // destroys g
 	}
 	OGRCoordinateTransformation *ct = 
 		OGRCreateCoordinateTransformation(g[0]->getSpatialReference(), dest);
