@@ -3,7 +3,13 @@
 #include "Rcpp.h"
 
 #if defined(HAVE_PROJ_H) && !defined(ACCEPT_USE_OF_DEPRECATED_PROJ_API_H) // new api
-#include <proj.h>
+# include <proj.h>
+
+Rcpp::LogicalVector CPL_set_data_dir(std::string data_dir) {
+	const char *cp = data_dir.c_str();
+	proj_context_set_search_paths(PJ_DEFAULT_CTX, 1, &cp);
+	return true;
+}
 
 std::string CPL_proj_version(bool b = false) {
 
@@ -103,13 +109,18 @@ Rcpp::NumericMatrix CPL_proj_direct(Rcpp::CharacterVector from_to, Rcpp::Numeric
 }
 
 
-#else // if defined(HAVE_PROJ_H) && !defined(ACCEPT_USE_OF_DEPRECATED_PROJ_API_H) // new api
-#include <proj_api.h>
+#else // if defined(HAVE_PROJ_H) && !defined(ACCEPT_USE_OF_DEPRECATED_PROJ_API_H) i.e., old proj_api:
+# include <proj_api.h>
 
 #if PJ_VERSION >= 600
 # define PROJ6 1
 #endif
 
+// [[Rcpp::export]]
+Rcpp::LogicalVector CPL_set_data_dir(std::string data_dir) { // #nocov start
+  return false;
+}                                                            // #nocov end
+
 #if PJ_VERSION == 480
 extern "C" {
 FILE *pj_open_lib(projCtx, const char *, const char *);
